@@ -34,7 +34,7 @@ class TreebeardEnv(BaseModel):
 
 
 class TreebeardConfig(BaseModel):
-    notebooks: Tuple[str, ...] = tuple()
+    notebooks: Tuple[str, ...] = tuple(["**/*.ipynb"])
     output_dirs: Tuple[str, ...] = tuple(["output"])
     ignore: Tuple[str, ...] = ()
     secret: Tuple[str, ...] = ()
@@ -44,7 +44,16 @@ class TreebeardConfig(BaseModel):
         deglobbed_notebooks = []
         for pattern in self.notebooks:
             deglobbed_notebooks.extend(sorted(glob(pattern, recursive=True)))
-        return deglobbed_notebooks
+        if len(deglobbed_notebooks) == 0:
+            raise Exception(
+                f"No notebooks found in project! Searched for {self.notebooks}"
+            )
+
+        ignored_notebooks = []
+        for pattern in self.ignore:
+            ignored_notebooks.extend(sorted(glob(pattern, recursive=True)))
+
+        return [nb for nb in deglobbed_notebooks if nb not in ignored_notebooks]
 
 
 env = "production"
@@ -83,9 +92,11 @@ def validate_notebook_directory(
         fatal_exit("No account config detected! Please run `treebeard configure`")
 
     if not Path("treebeard.yaml").is_file():
-        fatal_exit(
-            "treebeard.yaml file not found! `treebeard setup` fetches an example."
+        click.secho(
+            "Warning: treebeard.yaml file not found! `treebeard setup` fetches an example.",
+            fg="yellow",
         )
+        click.echo("Using defaults: notebooks: - '**/*.ipynb' output_dirs: - 'outputs'")
 
     notebook_files = treebeard_config.get_deglobbed_notebooks()
     if not notebook_files:
