@@ -1,6 +1,8 @@
 import configparser
 import json
+import os
 import sys
+from pathlib import Path
 from typing import Optional
 
 import click
@@ -73,3 +75,10 @@ def sanitise_notebook_id(notebook_id: str) -> str:
     out = notebook_id.replace("_", "-")
     out = out.replace(" ", "-")
     return out.lower()
+
+
+def create_example_yaml():
+    dirname = os.path.split(os.path.abspath(__file__))[0]
+    with open(Path(f"{dirname}/example_treebeard.yaml"), "rb") as f:
+        open("treebeard.yaml", "wb").write(f.read())
+    return
